# dhparams defined type
#
# Generate a Strong, Unique Diffie Hellman Group. A few fixed groups are used by millions of servers,
# which makes them an optimal target for precomputation, and potential eavesdropping. Administrators
# should generate unique, 2048-bit or stronger Diffie-Hellman groups using "safe" primes for each
# website or server.
#
# Due to the version of openssl and apache we are using, in order to pass in a custom set of DH primes,
# it must be appended to the SSL certificate being used.
#
# @param dhparam_cert_target [String] The absolute file path to the end cert file being generated.
# @param ssl_certificate_file [String] The absolute file path to the SSL certificate to be used.
# @param dhparam_cert_group [String] The name of the group assigned to the certs.
# @param dhparam_cert_mode [String] The file mode of the dhparams and ssl cert file.
# @param dhparam_cert_owner [String] The name of the user assigned to the certificate.
# @param dhparam_file [String] The absolute file path to the DH Prime file.
# @param dhparam_group_size [String] The bit size for the generated DH groups.
define puppet_enterprise::console::dhparam(
  $dhparam_cert_target,
  $ssl_certificate_file,
  $dhparam_cert_group = $puppet_enterprise::params::root_group,
  $dhparam_cert_mode  = $puppet_enterprise::params::root_mode,
  $dhparam_cert_owner = $puppet_enterprise::params::root_user,
  $dhparam_file       = $title,
) {

  pe_concat { $dhparam_cert_target:
    ensure  => present,
    owner   => $dhparam_cert_owner,
    group   => $dhparam_cert_group,
    mode    => $dhparam_cert_mode,
    notify  => Service['pe-httpd'],
  }

  pe_concat::fragment { "DH SSL Certificate concat fragement for ${dhparam_cert_target}":
    target => $dhparam_cert_target,
    source => $ssl_certificate_file,
    order  => '01',
  }

  pe_concat::fragment { "DH Prime concat fragment for ${dhparam_cert_target}":
    target  => $dhparam_cert_target,
    source  => $dhparam_file,
    order   => '02',
  }
}
